==> bem-components-3.1.2.tgz: package/common.blocks/menu/menu.bh.js <==
module.exports = function(bh) {

    bh.match('menu', function(ctx, json) {
        var mods = ctx.mods(),
            attrs = { role : 'menu' };

        ctx
            .tParam('menuMods', mods)
            .mix({ elem : 'control' });

        if(mods.disabled) {
            attrs['aria-disabled'] = 'true';
            ctx.js({ tabIndex : 0 });
        } else {
            attrs.tabindex = 0;
            ctx.js(true);
        }

        ctx.attrs(attrs);

        var firstItem,
            checkedItems = [];

        if(json.content) {
            var isValDef = typeof json.val !== 'undefined',
                isModeCheck = ctx.mod('mode') === 'check',
                containsVal = function(val) {
                    return isValDef &&
                        (isModeCheck?
                            json.val.indexOf(val) > -1 :
                            json.val === val);
                },
                iterateItems = function(content) {
                    var i = 0, itemOrGroup;
                    while(itemOrGroup = content[i++]) {
                        if(itemOrGroup.block === 'menu-item') {
                            firstItem || (firstItem = itemOrGroup);
                            if(containsVal(itemOrGroup.val)) {
                                (itemOrGroup.mods = itemOrGroup.mods || {}).checked = true;
                                checkedItems.push(itemOrGroup);
                            }
                        } else if(itemOrGroup.content) { // menu__group
                            iterateItems(itemOrGroup.content);
                        }
                    }
                };

            if(!Array.isArray(json.content)) throw Error('menu: content must be an array of the menu items');

            iterateItems(json.content);
        }

        ctx
            .tParam('firstItem', firstItem)
            .tParam('checkedItems', checkedItems);
    });
};

==> bem-components-5.1.1.tgz: package/common.blocks/menu/menu.bh.js <==
module.exports = function(bh) {

    bh.match('menu', function(ctx, json) {
        var mods = ctx.mods(),
            attrs = { role : 'menu' };

        ctx
            .tParam('menuMods', mods)
            .mix({ elem : 'control' });

        if(mods.disabled) {
            attrs['aria-disabled'] = 'true';
            ctx.js({ tabIndex : 0 });
        } else {
            attrs.tabindex = 0;
            ctx.js(true);
        }

        ctx.attrs(attrs);

        var firstItem,
            checkedItems = [];

        if(json.content) {
            var isValDef = typeof json.val !== 'undefined',
                isModeCheck = ctx.mod('mode') === 'check',
                containsVal = function(val) {
                    return isValDef &&
                        (isModeCheck?
                            json.val.indexOf(val) > -1 :
                            json.val === val);
                },
                iterateItems = function(content) {
                    var i = 0, itemOrGroup;
                    while(itemOrGroup = content[i++]) {
                        if(itemOrGroup.elem === 'item') {
                            firstItem || (firstItem = itemOrGroup);
                            if(containsVal(itemOrGroup.val)) {
                                (itemOrGroup.elemMods = itemOrGroup.elemMods || {}).checked = true;
                                checkedItems.push(itemOrGroup);
                            }
                        } else if(itemOrGroup.content) { // menu__group
                            iterateItems(itemOrGroup.content);
                        }
                    }
                };

            if(!Array.isArray(json.content)) throw Error('menu: content must be an array of the menu items');

            iterateItems(json.content);
        }

        ctx
            .tParam('firstItem', firstItem)
            .tParam('checkedItems', checkedItems);
    });
};
